package com.iprj.apoo.crmpv.controller;

import com.iprj.apoo.crmpv.model.dao.CategoriaDAO;
import com.iprj.apoo.crmpv.model.entity.Categoria;
import com.iprj.apoo.crmpv.model.json.CategoriaFactory;
import com.iprj.apoo.crmpv.util.JSONUtil;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * Created by guilherme on 01/07/15.
 */
@Controller
@RequestMapping("/categoria")
public class CategoriaController {

    @RequestMapping(method = RequestMethod.GET)
    public ModelAndView index() {
        return new ModelAndView("categoria");
    }

    @RequestMapping(value = {"/insert"}, method = RequestMethod.POST, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String insert(@RequestBody String data, HttpServletResponse response) {
        try {
            Categoria categoria = new CategoriaFactory().getFromJSON(data);
            CategoriaDAO dao = new CategoriaDAO();
            dao.insert(categoria);
            return null;
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/update"}, method = RequestMethod.POST, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String update(@RequestBody String data, HttpServletResponse response) {
        try {
            Categoria categoria = new CategoriaFactory().getFromJSON(data);
            CategoriaDAO dao = new CategoriaDAO();
            dao.update(categoria);
            return null;
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/delete/{id}"}, method = RequestMethod.GET, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String delete(@PathVariable long id, HttpServletResponse response) {
        try {
            CategoriaDAO dao = new CategoriaDAO();
            dao.delete(id);
            return null;
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/get/{id}"}, method = RequestMethod.GET, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String get(@PathVariable long id, HttpServletResponse response) {
        try {
            CategoriaDAO dao = new CategoriaDAO();
            Categoria categoria = dao.getById(id);
            if (categoria != null) {
                return new CategoriaFactory().parseToJSON(categoria);
            } else {
                response.setStatus(HttpServletResponse.SC_NOT_FOUND);
                return null;
            }
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/get"}, method = RequestMethod.GET, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String get(HttpServletResponse response) {
        try {
            CategoriaDAO dao = new CategoriaDAO();
            List<Categoria> list = dao.getAll();
            return new CategoriaFactory().parseCollectionToJSON(list);
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }


}
