package com.iprj.apoo.crmpv.controller;

import com.iprj.apoo.crmpv.model.dao.ClienteDAO;
import com.iprj.apoo.crmpv.model.entity.Cliente;
import com.iprj.apoo.crmpv.model.json.ClienteFactory;
import com.iprj.apoo.crmpv.util.JSONUtil;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * Created by guilherme on 01/07/15.
 */
@Controller
@RequestMapping("/cliente")
public class ClienteController {

    @RequestMapping(method = RequestMethod.GET)
    public ModelAndView index() {
        return new ModelAndView("cliente");
    }

    @RequestMapping(value = {"/insert"}, method = RequestMethod.POST, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String insert(@RequestBody String data, HttpServletResponse response) {
        try {
            Cliente cliente = new ClienteFactory().getFromJSON(data);
            ClienteDAO dao = new ClienteDAO();
            dao.insert(cliente);
            return null;
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/update"}, method = RequestMethod.POST, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String update(@RequestBody String data, HttpServletResponse response) {
        try {
            Cliente cliente = new ClienteFactory().getFromJSON(data);
            ClienteDAO dao = new ClienteDAO();
            dao.update(cliente);
            return null;
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/delete/{id}"}, method = RequestMethod.GET, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String delete(@PathVariable long id, HttpServletResponse response) {
        try {
            ClienteDAO dao = new ClienteDAO();
            dao.delete(id);
            return null;
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/get/{id}"}, method = RequestMethod.GET, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String get(@PathVariable long id, HttpServletResponse response) {
        try {
            ClienteDAO dao = new ClienteDAO();
            Cliente cliente = dao.getById(id);
            if (cliente != null) {
                return new ClienteFactory().parseToJSON(cliente);
            } else {
                response.setStatus(HttpServletResponse.SC_NOT_FOUND);
                return null;
            }
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/get"}, method = RequestMethod.GET, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String get(HttpServletResponse response) {
        try {
            ClienteDAO dao = new ClienteDAO();
            List<Cliente> list = dao.getAll();
            return new ClienteFactory().parseCollectionToJSON(list);
        } catch (Exception e) {
            e.printStackTrace();
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

}
