package com.iprj.apoo.crmpv.controller;

import com.iprj.apoo.crmpv.model.dao.ProdutoDAO;
import com.iprj.apoo.crmpv.model.entity.Produto;
import com.iprj.apoo.crmpv.model.json.ProdutoFactory;
import com.iprj.apoo.crmpv.util.JSONUtil;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * Created by guilherme on 01/07/15.
 */
@Controller
@RequestMapping("/produto")
public class ProdutoController {

    @RequestMapping(method = RequestMethod.GET)
    public ModelAndView index() {
        return new ModelAndView("produto");
    }

    @RequestMapping(value = {"/insert"}, method = RequestMethod.POST, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String insert(@RequestBody String data, HttpServletResponse response) {
        try {
            Produto produto = new ProdutoFactory().getFromJSON(data);
            ProdutoDAO dao = new ProdutoDAO();
            dao.insert(produto);
            return null;
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/update"}, method = RequestMethod.POST, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String update(@RequestBody String data, HttpServletResponse response) {
        try {
            Produto produto = new ProdutoFactory().getFromJSON(data);
            ProdutoDAO dao = new ProdutoDAO();
            dao.update(produto);
            return null;
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/delete/{id}"}, method = RequestMethod.GET, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String delete(@PathVariable long id, HttpServletResponse response) {
        try {
            ProdutoDAO dao = new ProdutoDAO();
            dao.delete(id);
            return null;
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/get/{id}"}, method = RequestMethod.GET, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String get(@PathVariable long id, HttpServletResponse response) {
        try {
            ProdutoDAO dao = new ProdutoDAO();
            Produto produto = dao.getById(id);
            if (produto != null) {
                return new ProdutoFactory().parseToJSON(produto);
            } else {
                response.setStatus(HttpServletResponse.SC_NOT_FOUND);
                return null;
            }
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/get"}, method = RequestMethod.GET, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String get(HttpServletResponse response) {
        try {
            ProdutoDAO dao = new ProdutoDAO();
            List<Produto> list = dao.getAll();
            return new ProdutoFactory().parseCollectionToJSON(list);
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }


}
