package com.iprj.apoo.crmpv.controller;

import com.iprj.apoo.crmpv.model.dao.CategoriaDAO;
import com.iprj.apoo.crmpv.model.dao.MediaConsumoDAO;
import com.iprj.apoo.crmpv.model.dao.ProdutoDAO;
import com.iprj.apoo.crmpv.model.dao.VendaDAO;
import com.iprj.apoo.crmpv.model.entity.Categoria;
import com.iprj.apoo.crmpv.model.entity.Filtro;
import com.iprj.apoo.crmpv.model.entity.MediaConsumo;
import com.iprj.apoo.crmpv.model.entity.Produto;
import com.iprj.apoo.crmpv.model.json.CategoriaFactory;
import com.iprj.apoo.crmpv.model.json.FiltroFactory;
import com.iprj.apoo.crmpv.model.json.MediaConsumoFactory;
import com.iprj.apoo.crmpv.model.json.ProdutoFactory;
import com.iprj.apoo.crmpv.util.JSONUtil;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * Created by rennan on 09/07/2015.
 */
@Controller
@RequestMapping("/relatorio")
public class RelatorioController {

    @RequestMapping(method = RequestMethod.GET)
    public ModelAndView index() {
        return new ModelAndView("relatorio");
    }

    @RequestMapping(value = "/media", method = RequestMethod.GET)
    public ModelAndView mediaPage() {
        return new ModelAndView("relatorio-media");
    }

    @RequestMapping(value = {"/vendas/filtro"}, method = RequestMethod.GET)
    public ModelAndView vendasFiltroPage() {
        return new ModelAndView("relatorio-vendasFiltro");
    }

    @RequestMapping(value = {"/quantidade/categoria"}, method = RequestMethod.GET)
    public ModelAndView qtdCategoriaPage() {
        return new ModelAndView("relatorio-quantidadeCategoria");
    }

    @RequestMapping(value = {"/quantidade/produto"}, method = RequestMethod.GET)
    public ModelAndView qtdProdutoPage() {
        return new ModelAndView("relatorio-quantidadeProduto");
    }


    @RequestMapping(value = "/media", method = RequestMethod.POST, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String mediaDados(HttpServletResponse response) {
        try {
            MediaConsumoDAO dao = new MediaConsumoDAO();
            List<MediaConsumo> list = dao.getAll();
            return new MediaConsumoFactory().parseCollectionToJSON(list);
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/vendas/filtro"}, method = RequestMethod.POST, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String vendasFiltroDados(HttpServletResponse response) {
        try {
            VendaDAO dao = new VendaDAO();
            List<Filtro> list = dao.filtro();
            return new FiltroFactory().parseCollectionToJSON(list);
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/quantidade/categoria"}, method = RequestMethod.POST, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String qtdCategoriaDados(HttpServletResponse response) {
        try {
            CategoriaDAO dao = new CategoriaDAO();
            List<Categoria> list = dao.getTotalVendido();
            return new CategoriaFactory().parseCollectionToJSON(list);
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/quantidade/produto"}, method = RequestMethod.POST, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String qtdProdutoDados(HttpServletResponse response) {
        try {
            ProdutoDAO dao = new ProdutoDAO();
            List<Produto> list = dao.getTotalVendido();
            return new ProdutoFactory().parseCollectionToJSON(list);
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/vendas/filtro/{idCli}"}, method = RequestMethod.GET, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String vendasFiltroDadosId(@PathVariable long idCli, HttpServletResponse response) {
        try {
            VendaDAO dao = new VendaDAO();
            List<Filtro> list = dao.filtro(idCli);
            return new FiltroFactory().parseCollectionToJSON(list);
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/media/{id}"}, method = RequestMethod.GET, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String mediaDadosId(@PathVariable long id, HttpServletResponse response) {
        try {
            MediaConsumoDAO dao = new MediaConsumoDAO();
            List<MediaConsumo> list = dao.getAllById(id);
            return new MediaConsumoFactory().parseCollectionToJSON(list);
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }
}
