package com.iprj.apoo.crmpv.controller;

import com.iprj.apoo.crmpv.model.dao.UsuarioDAO;
import com.iprj.apoo.crmpv.model.entity.Usuario;
import com.iprj.apoo.crmpv.model.json.UsuarioFactory;
import com.iprj.apoo.crmpv.util.JSONUtil;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * Created by guilherme on 01/07/15.
 */
@Controller
@RequestMapping("/usuario")
public class UsuarioController {

    @RequestMapping(method = RequestMethod.GET)
    public ModelAndView index() {
        return new ModelAndView("usuario");
    }

    @RequestMapping(value = {"/insert"}, method = RequestMethod.POST, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String insert(@RequestBody String data, HttpServletResponse response) {
        try {
            Usuario usuario = new UsuarioFactory().getFromJSON(data);
            UsuarioDAO dao = new UsuarioDAO();
            dao.insert(usuario);
            return null;
        } catch (Exception e) {
            e.printStackTrace();
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/update"}, method = RequestMethod.POST, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String update(@RequestBody String data, HttpServletResponse response) {
        try {
            Usuario usuario = new UsuarioFactory().getFromJSON(data);
            UsuarioDAO dao = new UsuarioDAO();
            dao.update(usuario);
            return null;
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/delete/{id}"}, method = RequestMethod.GET, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String delete(@PathVariable long id, HttpServletResponse response) {
        try {
            UsuarioDAO dao = new UsuarioDAO();
            dao.delete(id);
            return null;
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/get/{id}"}, method = RequestMethod.GET, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String get(@PathVariable long id, HttpServletResponse response) {
        try {
            UsuarioDAO dao = new UsuarioDAO();
            Usuario usuario = dao.getById(id);
            if (usuario != null) {
                return new UsuarioFactory().parseToJSON(usuario);
            } else {
                response.setStatus(HttpServletResponse.SC_NOT_FOUND);
                return null;
            }
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/get"}, method = RequestMethod.GET, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String get(HttpServletResponse response) {
        try {
            UsuarioDAO dao = new UsuarioDAO();
            List<Usuario> list = dao.getAll();
            return new UsuarioFactory().parseCollectionToJSON(list);
        } catch (Exception e) {
            e.printStackTrace();
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

}
