package com.iprj.apoo.crmpv.controller;

import com.iprj.apoo.crmpv.core.Sistema;
import com.iprj.apoo.crmpv.model.dao.VendaDAO;
import com.iprj.apoo.crmpv.model.entity.Venda;
import com.iprj.apoo.crmpv.model.json.VendaFactory;
import com.iprj.apoo.crmpv.util.JSONUtil;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * Created by guilherme on 01/07/15.
 */
@Controller
@RequestMapping("/venda")
public class VendaController {

    @RequestMapping(method = RequestMethod.GET)
    public ModelAndView index() {
        return new ModelAndView("venda");
    }

    @RequestMapping(value = {"/insert"}, method = RequestMethod.POST, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String insert(@RequestBody String data, HttpServletResponse response) {
        try {
            Venda venda = new VendaFactory().getFromJSON(data);
            VendaDAO dao = new VendaDAO();
            Sistema.getInstance().calcularPrevisoes(venda);
            dao.insert(venda);
            return null;
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/update"}, method = RequestMethod.POST, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String update(@RequestBody String data, HttpServletResponse response) {
        try {
            Venda venda = new VendaFactory().getFromJSON(data);
            VendaDAO dao = new VendaDAO();
            dao.update(venda);
            return null;
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/delete/{id}"}, method = RequestMethod.GET, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String delete(@PathVariable long id, HttpServletResponse response) {
        try {
            VendaDAO dao = new VendaDAO();
            dao.delete(id);
            return null;
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/get/{id}"}, method = RequestMethod.GET, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String get(@PathVariable long id, HttpServletResponse response) {
        try {
            VendaDAO dao = new VendaDAO();
            Venda venda = dao.getById(id);
            if (venda != null) {
                return new VendaFactory().parseToJSON(venda);
            } else {
                response.setStatus(HttpServletResponse.SC_NOT_FOUND);
                return null;
            }
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

    @RequestMapping(value = {"/get"}, method = RequestMethod.GET, produces = "application/json; charset=utf-8")
    public
    @ResponseBody
    String get(HttpServletResponse response) {
        try {
            VendaDAO dao = new VendaDAO();
            List<Venda> list = dao.getAll();
            return new VendaFactory().parseCollectionToJSON(list);
        } catch (Exception e) {
            int status = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
            response.setStatus(status);
            return JSONUtil.serializeError(status, e);
        }
    }

}
