package com.iprj.apoo.crmpv.core;

import com.iprj.apoo.crmpv.model.dao.MediaConsumoDAO;
import com.iprj.apoo.crmpv.model.entity.*;

import java.util.Calendar;
import java.util.Date;

/**
 * Created by Rennan on 08/07/15.
 */
public class CalculadorMediaConsumo implements Calculador {

    @Override
    public Date calcularPrevisao(Venda venda, ItemVenda item) {
        try {
            MediaConsumoDAO dao = new MediaConsumoDAO();
            long idCli = venda.getCliente().getId();
            long idProd = item.getProduto().getId();
            MediaConsumo mediaConsumo = dao.getById(idCli, idProd);
            if (mediaConsumo != null) {
                double media = calcularMedia(mediaConsumo, venda);
                long total = mediaConsumo.getTotalComprado() + item.getQuantidade();
                dao.update(media, total, mediaConsumo);
                return calcularData(venda, item, media);
            } else {
                Cliente cli = venda.getCliente();
                Produto prod = item.getProduto();
                Date priComp = venda.getData();
                long totComp = item.getQuantidade();
                mediaConsumo = new MediaConsumo(cli, prod, 0, priComp, totComp);
                dao.insert(mediaConsumo);
                return null;
            }
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }

    public double calcularMedia(MediaConsumo mediaConsumo, Venda venda) {
        Date priComp = mediaConsumo.getPrimeiraCompra();
        long totComp = mediaConsumo.getTotalComprado();
        Date data = venda.getData();
        int dias = (int) ((data.getTime() - priComp.getTime()) / 86400000);
        return (double) (30 * totComp / dias);
    }

    public Date calcularData(Venda venda, ItemVenda itemVenda, double mediaConsumo) {
        Calendar c = Calendar.getInstance();
        Date dataVenda = venda.getData();
        int qtd = itemVenda.getQuantidade();
        int dias = (int) (30 * qtd / mediaConsumo);
        c.setTime(dataVenda);
        c.add(Calendar.DATE, +dias);
        return c.getTime();
    }
}
