package com.iprj.apoo.crmpv.core;

import com.iprj.apoo.crmpv.model.dao.NotificacaoDAO;
import com.iprj.apoo.crmpv.model.entity.*;

import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

/**
 * Created by Rennan on 08/07/15.
 */
public class Sistema {

    private static Sistema instance;

    private Sistema() {
    }

    public static Sistema getInstance() {
        if (instance == null) {
            instance = new Sistema();
        }
        return instance;
    }

    public void calcularPrevisoes(Venda venda) {
        HashMap<Produto, Date> previsoes = new HashMap<>();
        Calculador calculador = new CalculadorMediaConsumo();
        Iterator<ItemVenda> itens = venda.getItens();
        while (itens.hasNext()) {
            ItemVenda item = itens.next();
            Date previsao = calculador.calcularPrevisao(venda, item);
            Produto produto = item.getProduto();
            previsoes.put(produto, previsao);
        }
        gerarNotificacoes(venda, previsoes);
    }

    private void gerarNotificacoes(Venda venda, HashMap<Produto, Date> previsoes) {
        try {
            NotificacaoDAO dao = new NotificacaoDAO();
            long idCli = venda.getCliente().getId();
            for (Map.Entry<Produto, Date> entry : previsoes.entrySet()) {
                Produto produto = entry.getKey();
                Date previsao = entry.getValue();
                if (previsao != null) {
                    Notificacao notificacao = dao.getById(idCli, produto.getId());
                    if (notificacao != null) {
                        notificacao.setDataPrevisao(previsao);
                        dao.update(notificacao);
                    } else {
                        Cliente cliente = venda.getCliente();
                        notificacao = new Notificacao(cliente, produto);
                        notificacao.setDataPrevisao(previsao);
                        dao.insert(notificacao);
                    }
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
