package com.iprj.apoo.crmpv.model.dao;

import com.iprj.apoo.crmpv.model.entity.Categoria;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by guilherme on 01/07/15.
 */
public class CategoriaDAO extends DAO<Categoria> {

    @Override
    public Categoria getById(long id) throws SQLException {
        String sql = "SELECT * FROM Categoria AS c WHERE c.id = ?";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ps.setLong(1, id);
        ResultSet result = ps.executeQuery();
        if (result.next()) {
            return parseResultSet(result);
        } else {
            return null;
        }
    }

    @Override
    public List<Categoria> getAll() throws SQLException {
        String sql = "SELECT * FROM Categoria";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ResultSet result = ps.executeQuery();
        List<Categoria> list = new ArrayList<>();
        while (result.next()) {
            list.add(parseResultSet(result));
        }
        return list;
    }

    public List<Categoria> getTotalVendido() throws SQLException {
        String sql = "SELECT *, SUM(item.quantidade) AS totalVendido FROM Categoria categoria " +
                "INNER JOIN Produto produto ON categoria.id = produto.idCategoria " +
                "INNER JOIN ItemVenda item ON produto.id = item.idProduto " +
                "GROUP BY categoria.nome ORDER BY totalVendido DESC";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ResultSet result = ps.executeQuery();
        List<Categoria> list = new ArrayList<>();
        while (result.next()) {
            list.add(parseResultTotalSet(result));
        }
        return list;
    }

    @Override
    public void insert(Categoria categoria) throws SQLException {
        String sql = "INSERT INTO Categoria(nome) VALUES(?)";
        PreparedStatement ps = getConnection().prepareStatement(sql, Statement.RETURN_GENERATED_KEYS);
        ps.setString(1, categoria.getNome());
        ps.executeUpdate();
        ResultSet result = ps.getGeneratedKeys();
        if (result.next()) {
            long id = result.getLong(1);
            categoria.setId(id);
        }
    }

    @Override
    public void update(Categoria categoria) throws SQLException {
        String sql = "UPDATE Categoria SET nome = ? WHERE id = ?";
        PreparedStatement ps = getConnection().prepareStatement(sql, Statement.RETURN_GENERATED_KEYS);
        ps.setString(1, categoria.getNome());
        ps.setLong(2, categoria.getId());
        ps.executeUpdate();
    }

    @Override
    public void delete(long id) throws SQLException {
        String sql = "DELETE FROM Categoria WHERE id = ?";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ps.setLong(1, id);
        ps.executeUpdate();
    }

    @Override
    public Categoria parseResultSet(ResultSet resultSet) throws SQLException {
        Categoria categoria = new Categoria();
        categoria.setId(resultSet.getLong("id"));
        categoria.setNome(resultSet.getString("nome"));
        return categoria;
    }

    public Categoria parseResultTotalSet(ResultSet resultSet) throws SQLException {
        Categoria categoria = new Categoria();
        categoria.setId(resultSet.getLong("id"));
        categoria.setNome(resultSet.getString("nome"));
        categoria.setTotalVendido(resultSet.getLong("totalVendido"));
        return categoria;
    }

}
