package com.iprj.apoo.crmpv.model.dao;

import com.iprj.apoo.crmpv.model.entity.Cliente;
import com.iprj.apoo.crmpv.model.entity.Endereco;
import com.iprj.apoo.crmpv.model.entity.PessoaFisica;
import com.iprj.apoo.crmpv.model.entity.PessoaJuridica;
import com.iprj.apoo.crmpv.util.DateUtil;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by guilherme on 03/07/15.
 */
public class ClienteDAO extends DAO<Cliente> {

    @Override
    public Cliente getById(long id) throws SQLException {
        String sql = "SELECT * FROM Cliente cliente " +
                "INNER JOIN Endereco endereco ON endereco.idCliente = cliente.id " +
                "WHERE cliente.id = ?";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ps.setLong(1, id);
        ResultSet result = ps.executeQuery();
        if (result.next()) {
            return parseResultSet(result);
        } else {
            return null;
        }
    }

    @Override
    public List<Cliente> getAll() throws SQLException {
        String sql = "SELECT * FROM Cliente cliente " +
                "LEFT JOIN Usuario usuario ON usuario.idCliente = cliente.id " +
                "INNER JOIN Endereco endereco ON endereco.idCliente = cliente.id " +
                "WHERE usuario.idCliente IS NULL";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ResultSet result = ps.executeQuery();
        List<Cliente> list = new ArrayList<>();
        while (result.next()) {
            list.add(parseResultSet(result));
        }
        return list;
    }

    @Override
    public void insert(Cliente entity) throws SQLException {
        String sqlCliente = "INSERT INTO Cliente(nome, telefone, email, cpf, dataNascimento, cnpj, type) VALUES(?,?,?,?,?,?,?)";
        String sqlEndereco = "INSERT INTO Endereco(rua,numero,complemento,bairro,cidade,uf,cep, idCliente) VALUES(?,?,?,?,?,?,?,?)";

        PreparedStatement ps = getConnection().prepareStatement(sqlCliente, Statement.RETURN_GENERATED_KEYS);
        ps.setString(1, entity.getNome());
        ps.setString(2, entity.getTelefone());
        ps.setString(3, entity.getEmail());
        if (entity instanceof PessoaFisica) {
            PessoaFisica pessoaFisica = (PessoaFisica) entity;
            ps.setString(4, pessoaFisica.getCpf());
            ps.setString(5, DateUtil.getDateString(pessoaFisica.getDataNascimento()));
            ps.setString(6, null);
            ps.setString(7, PessoaFisica.TYPE_NAME);
        } else if (entity instanceof PessoaJuridica) {
            PessoaJuridica pessoaJuridica = (PessoaJuridica) entity;
            ps.setString(4, null);
            ps.setString(5, null);
            ps.setString(6, pessoaJuridica.getCnpj());
            ps.setString(7, PessoaJuridica.TYPE_NAME);
        }
        ps.executeUpdate();

        ResultSet result = ps.getGeneratedKeys();
        if (result.next()) {
            long id = result.getLong(1);
            entity.setId(id);
        }

        Endereco endereco = entity.getEndereco();
        ps = getConnection().prepareStatement(sqlEndereco, Statement.RETURN_GENERATED_KEYS);
        ps.setString(1, endereco.getRua());
        ps.setInt(2, endereco.getNumero());
        ps.setString(3, endereco.getComplemento());
        ps.setString(4, endereco.getBairro());
        ps.setString(5, endereco.getCidade());
        ps.setString(6, endereco.getUf());
        ps.setString(7, endereco.getCep());
        ps.setLong(8, entity.getId());
        ps.executeUpdate();
        result = ps.getGeneratedKeys();
        if (result.next()) {
            long id = result.getLong(1);
            endereco.setId(id);
        }


    }

    @Override
    public void update(Cliente entity) throws SQLException {
        String sqlCliente = "UPDATE Cliente SET nome=?,telefone=?,email=?,cpf=?,dataNascimento=?,cnpj=?,type=? WHERE id=?";
        String sqlEndereco = "UPDATE Endereco SET rua=?,numero=?,complemento=?,bairro=?,cidade=?,uf=?,cep=? WHERE id=?";

        PreparedStatement ps = getConnection().prepareStatement(sqlCliente, Statement.RETURN_GENERATED_KEYS);
        ps.setString(1, entity.getNome());
        ps.setString(2, entity.getTelefone());
        ps.setString(3, entity.getEmail());
        if (entity instanceof PessoaFisica) {
            PessoaFisica pessoaFisica = (PessoaFisica) entity;
            ps.setString(4, pessoaFisica.getCpf());
            ps.setString(5, DateUtil.getDateString(pessoaFisica.getDataNascimento()));
            ps.setString(6, null);
            ps.setString(7, PessoaFisica.TYPE_NAME);
        } else if (entity instanceof PessoaJuridica) {
            PessoaJuridica pessoaJuridica = (PessoaJuridica) entity;
            ps.setString(4, null);
            ps.setString(5, null);
            ps.setString(6, pessoaJuridica.getCnpj());
            ps.setString(7, PessoaJuridica.TYPE_NAME);
        }
        ps.setLong(8, entity.getId());
        ps.executeUpdate();

        Endereco endereco = entity.getEndereco();
        ps = getConnection().prepareStatement(sqlEndereco);
        ps.setString(1, endereco.getRua());
        ps.setInt(2, endereco.getNumero());
        ps.setString(3, endereco.getComplemento());
        ps.setString(4, endereco.getBairro());
        ps.setString(5, endereco.getCidade());
        ps.setString(6, endereco.getUf());
        ps.setString(7, endereco.getCep());
        ps.setLong(8, endereco.getId());
        ps.executeUpdate();

    }

    @Override
    public void delete(long id) throws SQLException {
        String sql = "DELETE FROM Cliente WHERE id = ?";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ps.setLong(1, id);
        ps.executeUpdate();
    }

    @Override
    public Cliente parseResultSet(ResultSet resultSet) throws SQLException {
        Endereco endereco = new Endereco();
        endereco.setId(resultSet.getLong("endereco.id"));
        endereco.setRua(resultSet.getString("endereco.rua"));
        endereco.setNumero(resultSet.getInt("endereco.numero"));
        endereco.setComplemento(resultSet.getString("endereco.complemento"));
        endereco.setBairro(resultSet.getString("endereco.bairro"));
        endereco.setCidade(resultSet.getString("endereco.cidade"));
        endereco.setUf(resultSet.getString("endereco.uf"));
        endereco.setCep(resultSet.getString("endereco.cep"));

        String type = resultSet.getString("cliente.type");
        if (type.equals(PessoaFisica.TYPE_NAME)) {
            PessoaFisica pessoaFisica = new PessoaFisica();
            pessoaFisica.setId(resultSet.getLong("cliente.id"));
            pessoaFisica.setNome(resultSet.getString("cliente.nome"));
            pessoaFisica.setTelefone(resultSet.getString("cliente.telefone"));
            pessoaFisica.setEmail(resultSet.getString("cliente.email"));
            pessoaFisica.setCpf(resultSet.getString("cliente.cpf"));
            pessoaFisica.setDataNascimento(DateUtil.getDate(resultSet.getString("cliente.dataNascimento")));
            pessoaFisica.setEndereco(endereco);
            return pessoaFisica;
        } else if (type.equals(PessoaJuridica.TYPE_NAME)) {
            PessoaJuridica pessoaJuridica = new PessoaJuridica();
            pessoaJuridica.setId(resultSet.getLong("cliente.id"));
            pessoaJuridica.setNome(resultSet.getString("cliente.nome"));
            pessoaJuridica.setTelefone(resultSet.getString("cliente.telefone"));
            pessoaJuridica.setEmail(resultSet.getString("cliente.email"));
            pessoaJuridica.setCnpj(resultSet.getString("cliente.cnpj"));
            pessoaJuridica.setEndereco(endereco);
            return pessoaJuridica;
        }

        return null;
    }

}
