package com.iprj.apoo.crmpv.model.dao;

import com.iprj.apoo.crmpv.model.entity.Cliente;
import com.iprj.apoo.crmpv.model.entity.MediaConsumo;
import com.iprj.apoo.crmpv.model.entity.Produto;
import com.iprj.apoo.crmpv.util.DateUtil;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by Rennan on 08/07/2015.
 */
public class MediaConsumoDAO extends DAO<MediaConsumo> {


    @Override
    public MediaConsumo getById(long id) throws SQLException {
        return null;
    }

    public MediaConsumo getById(long idCli, long idProd) throws SQLException {
        String sql = "SELECT * FROM MediaConsumo mediaconsumo " +
                "INNER JOIN Cliente cliente ON mediaconsumo.idCliente = cliente.id " +
                "INNER JOIN Endereco endereco ON endereco.idCliente = cliente.id " +
                "INNER JOIN Produto produto ON mediaconsumo.idProduto = produto.id " +
                "INNER JOIN Categoria categoria ON categoria.id = produto.idCategoria " +
                "WHERE mediaconsumo.idCliente = ? AND mediaconsumo.idProduto = ?";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ps.setLong(1, idCli);
        ps.setLong(2, idProd);
        ResultSet result = ps.executeQuery();
        if (result.next()) {
            return parseResultSet(result);
        } else {
            return null;
        }
    }

    public List<MediaConsumo> getAllById(long id) throws SQLException {
        String sql = "SELECT * FROM MediaConsumo mediaconsumo " +
                "INNER JOIN Cliente cliente ON mediaconsumo.idCliente = cliente.id " +
                "INNER JOIN Endereco endereco ON endereco.idCliente = cliente.id " +
                "INNER JOIN Produto produto ON mediaconsumo.idProduto = produto.id " +
                "INNER JOIN Categoria categoria ON categoria.id = produto.idCategoria " +
                "WHERE mediaconsumo.idCliente = ? ORDER BY mediaconsumo.media DESC";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ps.setLong(1, id);
        ResultSet result = ps.executeQuery();
        List<MediaConsumo> list = new ArrayList<>();
        while (result.next()) {
            list.add(parseResultSet(result));
        }
        return list;
    }

    @Override
    public List<MediaConsumo> getAll() throws SQLException {
        String sql = "SELECT * FROM MediaConsumo mediaconsumo " +
                "INNER JOIN Cliente cliente ON mediaconsumo.idCliente = cliente.id " +
                "INNER JOIN Endereco endereco ON endereco.idCliente = cliente.id " +
                "INNER JOIN Produto produto ON mediaconsumo.idProduto = produto.id " +
                "INNER JOIN Categoria categoria ON categoria.id = produto.idCategoria " +
                "ORDER BY mediaconsumo.idCliente, mediaconsumo.media";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ResultSet result = ps.executeQuery();
        List<MediaConsumo> list = new ArrayList<>();
        while (result.next()) {
            list.add(parseResultSet(result));
        }
        return list;
    }

    @Override
    public void insert(MediaConsumo entity) throws SQLException {
        String sql = "INSERT INTO mediaConsumo(idCliente, idProduto, media, primeiraCompra, totalComprado) VALUES(?, ?, ?, ?, ?)";
        PreparedStatement ps = getConnection().prepareStatement(sql, Statement.RETURN_GENERATED_KEYS);
        ps.setLong(1, entity.getCliente().getId());
        ps.setLong(2, entity.getProduto().getId());
        ps.setDouble(3, entity.getMedia());
        ps.setString(4, DateUtil.getDateString(entity.getPrimeiraCompra()));
        ps.setLong(5, entity.getTotalComprado());
        ps.executeUpdate();
    }

    @Override
    public void update(MediaConsumo entity) throws SQLException {
    }

    public void update(double media, long totalComprado, MediaConsumo entity) throws SQLException {
        String sql = "UPDATE mediaConsumo SET " +
                "media = ?, totalComprado = ? " +
                "WHERE idCliente = ? AND idProduto = ?";
        PreparedStatement ps = getConnection().prepareStatement(sql, Statement.RETURN_GENERATED_KEYS);
        ps.setDouble(1, media);
        ps.setLong(2, totalComprado);
        ps.setLong(3, entity.getCliente().getId());
        ps.setLong(4, entity.getProduto().getId());
        ps.executeUpdate();
    }

    @Override
    public void delete(long idCli) throws SQLException {

    }

    public void delete(long idCli, long idProd) throws SQLException {
        String sql = "DELETE FROM mediaConsumo WHERE idCliente = ? AND idProduto = ?";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ps.setLong(1, idCli);
        ps.setLong(2, idProd);
        ps.executeUpdate();
    }

    @Override
    public MediaConsumo parseResultSet(ResultSet resultSet) throws SQLException {
        ClienteDAO clienteDAO = new ClienteDAO();
        Cliente cliente = clienteDAO.parseResultSet(resultSet);//TODO MELHORAR (REDUZIR ACOPLAMENTO)

        ProdutoDAO produtoDAO = new ProdutoDAO();
        Produto produto = produtoDAO.parseResultSet(resultSet);

        MediaConsumo media = new MediaConsumo();
        media.setCliente(cliente);
        media.setProduto(produto);
        media.setMedia(resultSet.getDouble("mediaconsumo.media"));
        media.setPrimeiraCompra(DateUtil.getDate(resultSet.getString("mediaconsumo.primeiraCompra")));
        media.setTotalComprado(resultSet.getLong("mediaconsumo.totalComprado"));

        return media;
    }
}
