package com.iprj.apoo.crmpv.model.dao;

import com.iprj.apoo.crmpv.model.entity.Cliente;
import com.iprj.apoo.crmpv.model.entity.Notificacao;
import com.iprj.apoo.crmpv.model.entity.Produto;
import com.iprj.apoo.crmpv.util.DateUtil;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by Rennan on 08/07/2015.
 */
public class NotificacaoDAO extends DAO<Notificacao> {


    @Override
    public Notificacao getById(long id) throws SQLException {
        return null;
    }

    public Notificacao getById(long idCli, long idProd) throws SQLException {
        String sql = "SELECT * FROM Notificacao notificacao " +
                "INNER JOIN Cliente cliente ON notificacao.idCliente = cliente.id " +
                "INNER JOIN Endereco endereco ON endereco.idCliente = cliente.id " +
                "INNER JOIN Produto produto ON notificacao.idProduto = produto.id " +
                "INNER JOIN Categoria categoria ON categoria.id = produto.idCategoria " +
                "WHERE notificacao.idCliente = ? AND notificacao.idProduto = ?";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ps.setLong(1, idCli);
        ps.setLong(2, idProd);
        ResultSet result = ps.executeQuery();
        if (result.next()) {
            return parseResultSet(result);
        } else {
            return null;
        }
    }

    public List<Notificacao> getAllById(long id) throws SQLException {
        String sql = "SELECT * FROM Notificacao notificacao " +
                "INNER JOIN Cliente cliente ON notificacao.idCliente = cliente.id " +
                "INNER JOIN Endereco endereco ON endereco.idCliente = cliente.id " +
                "INNER JOIN Produto produto ON notificacao.idProduto = produto.id " +
                "INNER JOIN Categoria categoria ON categoria.id = produto.idCategoria " +
                "WHERE notificacao.idCliente = ?";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ps.setLong(1, id);
        ResultSet result = ps.executeQuery();
        List<Notificacao> list = new ArrayList<>();
        while (result.next()) {
            list.add(parseResultSet(result));
        }
        return list;
    }

    @Override
    public List<Notificacao> getAll() throws SQLException {
        String sql = "SELECT * FROM Notificacao notificacao " +
                "INNER JOIN Cliente cliente ON notificacao.idCliente = cliente.id " +
                "INNER JOIN Endereco endereco ON endereco.idCliente = cliente.id " +
                "INNER JOIN Produto produto ON notificacao.idProduto = produto.id " +
                "INNER JOIN Categoria categoria ON categoria.id = produto.idCategoria " +
                "ORDER BY notificacao.idCliente";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ResultSet result = ps.executeQuery();
        List<Notificacao> list = new ArrayList<>();
        while (result.next()) {
            Notificacao notificacao = parseResultSet(result);
            if (notificacao.getDataPrevisao() != null) {
                list.add(notificacao);
            }
        }
        return list;
    }

    @Override
    public void insert(Notificacao entity) throws SQLException {
        String sql = "INSERT INTO notificacao(idCliente, idProduto, dataPrevisao) VALUES(?, ?, ?)";
        PreparedStatement ps = getConnection().prepareStatement(sql, Statement.RETURN_GENERATED_KEYS);
        ps.setLong(1, entity.getCliente().getId());
        ps.setLong(2, entity.getProduto().getId());
        ps.setString(3, DateUtil.getDateString(entity.getDataPrevisao()));
        ps.executeUpdate();
    }

    @Override
    public void update(Notificacao entity) throws SQLException {
        String sql = "UPDATE notificacao SET dataPrevisao = ?" +
                "WHERE idCliente = ? AND idProduto = ?";
        PreparedStatement ps = getConnection().prepareStatement(sql, Statement.RETURN_GENERATED_KEYS);
        ps.setString(1, DateUtil.getDateString(entity.getDataPrevisao()));
        ps.setLong(2, entity.getCliente().getId());
        ps.setLong(3, entity.getProduto().getId());
        ps.executeUpdate();
    }

    @Override
    public void delete(long idCli) throws SQLException {

    }

    public void delete(long idCli, long idProd) throws SQLException {
        String sql = "DELETE FROM notificacao WHERE idCliente = ? AND idProduto = ?";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ps.setLong(1, idCli);
        ps.setLong(2, idProd);
        ps.executeUpdate();
    }

    @Override
    public Notificacao parseResultSet(ResultSet resultSet) throws SQLException {
        ClienteDAO clienteDAO = new ClienteDAO();
        Cliente cliente = clienteDAO.parseResultSet(resultSet);//TODO MELHORAR (REDUZIR ACOPLAMENTO)

        ProdutoDAO produtoDAO = new ProdutoDAO();
        Produto produto = produtoDAO.parseResultSet(resultSet);

        Notificacao notificacao = new Notificacao();
        notificacao.setCliente(cliente);
        notificacao.setProduto(produto);
        notificacao.setDataPrevisao(DateUtil.getDate(resultSet.getString("notificacao.dataPrevisao")));

        return notificacao;
    }
}
