package com.iprj.apoo.crmpv.model.dao;

import com.iprj.apoo.crmpv.model.entity.Categoria;
import com.iprj.apoo.crmpv.model.entity.Produto;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by guilherme on 01/07/15.
 */
public class ProdutoDAO extends DAO<Produto> {


    @Override
    public Produto getById(long id) throws SQLException {
        String sql = "SELECT * FROM Produto produto " +
                "INNER JOIN Categoria categoria ON produto.idCategoria = categoria.id " +
                "WHERE pproduto.id = ?";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ps.setLong(1, id);
        ResultSet result = ps.executeQuery();
        if (result.next()) {
            return parseResultSet(result);
        } else {
            return null;
        }
    }

    public List<Produto> getTotalVendido() throws SQLException {
        String sql = "SELECT *, SUM(item.quantidade) AS totalVendido FROM Produto produto " +
                "INNER JOIN Categoria categoria ON categoria.id = produto.idCategoria " +
                "INNER JOIN ItemVenda item ON produto.id = item.idProduto " +
                "GROUP BY produto.nome ORDER BY totalVendido DESC";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ResultSet result = ps.executeQuery();
        List<Produto> list = new ArrayList<>();
        while (result.next()) {
            list.add(parseResultTotalSet(result));
        }
        return list;
    }

    @Override
    public List<Produto> getAll() throws SQLException {
        String sql = "SELECT * FROM Produto produto " +
                "INNER JOIN Categoria categoria ON categoria.id = produto.idCategoria";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ResultSet result = ps.executeQuery();
        List<Produto> list = new ArrayList<>();
        while (result.next()) {
            list.add(parseResultSet(result));
        }
        return list;
    }

    @Override
    public void insert(Produto entity) throws SQLException {
        String sql = "INSERT INTO Produto(nome, codigo, preco, idCategoria) VALUES(?, ?, ?, ?)";
        PreparedStatement ps = getConnection().prepareStatement(sql, Statement.RETURN_GENERATED_KEYS);
        ps.setString(1, entity.getNome());
        ps.setString(2, entity.getCodigo());
        ps.setDouble(3, entity.getPreco());
        ps.setLong(4, entity.getCategoria().getId());
        ps.executeUpdate();
        ResultSet result = ps.getGeneratedKeys();
        if (result.next()) {
            long id = result.getLong(1);
            entity.setId(id);
        }
    }

    @Override
    public void update(Produto entity) throws SQLException {
        String sql = "UPDATE Produto SET nome = ?, codigo = ?, preco = ?, idCategoria = ? WHERE id = ?";
        PreparedStatement ps = getConnection().prepareStatement(sql, Statement.RETURN_GENERATED_KEYS);
        ps.setString(1, entity.getNome());
        ps.setString(2, entity.getCodigo());
        ps.setDouble(3, entity.getPreco());
        ps.setLong(4, entity.getCategoria().getId());
        ps.setLong(5, entity.getId());
        ps.executeUpdate();
    }

    @Override
    public void delete(long id) throws SQLException {
        String sql = "DELETE FROM Produto WHERE id = ?";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ps.setLong(1, id);
        ps.executeUpdate();
    }

    @Override
    public Produto parseResultSet(ResultSet resultSet) throws SQLException {
        Categoria categoria = new Categoria();
        categoria.setId(resultSet.getLong("categoria.id"));
        categoria.setNome(resultSet.getString("categoria.nome"));

        Produto produto = new Produto();
        produto.setId(resultSet.getLong("produto.id"));
        produto.setNome(resultSet.getString("produto.nome"));
        produto.setCodigo(resultSet.getString("produto.codigo"));
        produto.setPreco(resultSet.getDouble("produto.preco"));
        produto.setCategoria(categoria);

        return produto;
    }

    public Produto parseResultTotalSet(ResultSet resultSet) throws SQLException {
        Categoria categoria = new Categoria();
        categoria.setId(resultSet.getLong("categoria.id"));
        categoria.setNome(resultSet.getString("categoria.nome"));

        Produto produto = new Produto();
        produto.setId(resultSet.getLong("produto.id"));
        produto.setNome(resultSet.getString("produto.nome"));
        produto.setCodigo(resultSet.getString("produto.codigo"));
        produto.setPreco(resultSet.getDouble("produto.preco"));
        produto.setTotalVendido(resultSet.getLong("totalVendido"));
        produto.setCategoria(categoria);

        return produto;
    }
}
