package com.iprj.apoo.crmpv.model.dao;

import com.iprj.apoo.crmpv.model.entity.Cargo;
import com.iprj.apoo.crmpv.model.entity.Endereco;
import com.iprj.apoo.crmpv.model.entity.Usuario;
import com.iprj.apoo.crmpv.util.DateUtil;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by guilherme on 03/07/15.
 */
public class UsuarioDAO extends DAO<Usuario> {

    @Override
    public Usuario getById(long id) throws SQLException {
        String sql = "SELECT * FROM Usuario usuario " +
                "INNER JOIN Cliente cliente ON cliente.id = usuario.idCliente " +
                "INNER JOIN Endereco endereco ON endereco.idCliente = cliente.id " +
                "WHERE usuario.idCliente = ?";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ps.setLong(1, id);
        ResultSet result = ps.executeQuery();
        if (result.next()) {
            return parseResultSet(result);
        } else {
            return null;
        }
    }

    public Usuario getByUsername(String username) throws SQLException {
        String sql = "SELECT * FROM Usuario usuario " +
                "INNER JOIN Cliente cliente ON cliente.id = usuario.idCliente " +
                "INNER JOIN Endereco endereco ON endereco.idCliente = cliente.id " +
                "WHERE usuario.username LIKE ?";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ps.setString(1, username);
        ResultSet result = ps.executeQuery();
        if (result.next()) {
            return parseResultSet(result);
        } else {
            return null;
        }
    }

    @Override
    public List<Usuario> getAll() throws SQLException {
        String sql = "SELECT * FROM Usuario usuario " +
                "INNER JOIN Cliente cliente ON cliente.id = usuario.idCliente " +
                "INNER JOIN Endereco endereco ON endereco.idCliente = cliente.id";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ResultSet result = ps.executeQuery();
        List<Usuario> list = new ArrayList<>();
        while (result.next()) {
            list.add(parseResultSet(result));
        }
        return list;
    }

    @Override
    public void insert(Usuario entity) throws SQLException {
        ClienteDAO clienteDAO = new ClienteDAO();
        clienteDAO.insert(entity);

        String sql = "INSERT INTO Usuario(idCliente,username,password,cargo) VALUES(?,?,?,?)";
        PreparedStatement ps = getConnection().prepareStatement(sql, Statement.RETURN_GENERATED_KEYS);
        ps.setLong(1, entity.getId());
        ps.setString(2, entity.getUsername());
        ps.setString(3, entity.getPassword());
        ps.setString(4, entity.getCargo().toString());
        ps.executeUpdate();
    }

    @Override
    public void update(Usuario entity) throws SQLException {
        ClienteDAO clienteDAO = new ClienteDAO();
        clienteDAO.update(entity);

        String sql = "UPDATE Usuario SET username=?,password=?,cargo=? WHERE idCliente=?";
        PreparedStatement ps = getConnection().prepareStatement(sql, Statement.RETURN_GENERATED_KEYS);
        ps.setString(1, entity.getUsername());
        ps.setString(2, entity.getPassword());
        ps.setString(3, entity.getCargo().toString());
        ps.setLong(4, entity.getId());
        ps.executeUpdate();
    }

    @Override
    public void delete(long id) throws SQLException {
        String sql = "DELETE FROM Cliente WHERE id = ?";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ps.setLong(1, id);
        ps.executeUpdate();
    }

    @Override
    public Usuario parseResultSet(ResultSet resultSet) throws SQLException {
        Endereco endereco = new Endereco();
        endereco.setId(resultSet.getLong("endereco.id"));
        endereco.setRua(resultSet.getString("endereco.rua"));
        endereco.setNumero(resultSet.getInt("endereco.numero"));
        endereco.setComplemento(resultSet.getString("endereco.complemento"));
        endereco.setBairro(resultSet.getString("endereco.bairro"));
        endereco.setCidade(resultSet.getString("endereco.cidade"));
        endereco.setUf(resultSet.getString("endereco.uf"));
        endereco.setCep(resultSet.getString("endereco.cep"));

        Usuario usuario = new Usuario();
        usuario.setId(resultSet.getLong("cliente.id"));
        usuario.setNome(resultSet.getString("cliente.nome"));
        usuario.setTelefone(resultSet.getString("cliente.telefone"));
        usuario.setEmail(resultSet.getString("cliente.email"));
        usuario.setCpf(resultSet.getString("cliente.cpf"));
        usuario.setDataNascimento(DateUtil.getDate(resultSet.getString("cliente.dataNascimento")));
        usuario.setUsername(resultSet.getString("usuario.username"));
        usuario.setPassword(resultSet.getString("usuario.password"));
        usuario.setCargo(Cargo.valueOf(resultSet.getString("usuario.cargo")));
        usuario.setEndereco(endereco);
        return usuario;

    }

}
