package com.iprj.apoo.crmpv.model.dao;

import com.iprj.apoo.crmpv.model.entity.*;
import com.iprj.apoo.crmpv.util.DateUtil;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

/**
 * Created by guilherme on 06/07/15.
 */
public class VendaDAO extends DAO<Venda> {

    @Override
    public Venda getById(long id) throws SQLException {
        String sql = "SELECT * FROM Venda venda " +
                "INNER JOIN Pagamento pagamento ON pagamento.idVenda = venda.id " +
                "INNER JOIN Cliente cliente ON cliente.id = venda.idCliente " +
                "INNER JOIN Endereco endereco ON endereco.idCliente = cliente.id " +
                "WHERE venda.id = ?";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ps.setLong(1, id);
        ResultSet result = ps.executeQuery();
        if (result.next()) {
            Venda venda = parseResultSet(result);
            for (ItemVenda item : getItens(venda.getId())) {
                venda.addItem(item);
            }
            return venda;
        } else {
            return null;
        }

    }

    @Override
    public List<Venda> getAll() throws SQLException {
        String sql = "SELECT * FROM Venda venda " +
                "INNER JOIN Pagamento pagamento ON pagamento.idVenda = venda.id " +
                "INNER JOIN Cliente cliente ON cliente.id = venda.idCliente " +
                "INNER JOIN Endereco endereco ON endereco.idCliente = cliente.id ";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ResultSet result = ps.executeQuery();
        List<Venda> list = new ArrayList<>();
        while (result.next()) {
            Venda venda = parseResultSet(result);
            for (ItemVenda item : getItens(venda.getId())) {
                venda.addItem(item);
            }
            list.add(venda);
        }
        return list;
    }

    @Override
    public void insert(Venda entity) throws SQLException {
        String sqlCliente = "INSERT INTO Venda(data, idCliente) VALUES(?,?)";
        String sqlEndereco = "INSERT INTO Pagamento(descricao, efetuado, tipo, idVenda) VALUES(?,?,?,?)";

        PreparedStatement ps = getConnection().prepareStatement(sqlCliente, Statement.RETURN_GENERATED_KEYS);
        ps.setString(1, DateUtil.getDateString(entity.getData()));
        ps.setLong(2, entity.getCliente().getId());
        ps.executeUpdate();

        ResultSet result = ps.getGeneratedKeys();
        if (result.next()) {
            long id = result.getLong(1);
            entity.setId(id);
        }

        Pagamento pagamento = entity.getPagamento();
        ps = getConnection().prepareStatement(sqlEndereco, Statement.RETURN_GENERATED_KEYS);
        ps.setString(1, pagamento.getDescricao());
        ps.setBoolean(2, pagamento.isEfetuado());
        ps.setString(3, pagamento.getTipo().toString());
        ps.setLong(4, entity.getId());
        ps.executeUpdate();
        result = ps.getGeneratedKeys();
        if (result.next()) {
            long id = result.getLong(1);
            pagamento.setId(id);
        }

        insertItens(entity.getItens(), entity.getId());
    }

    @Override
    public void update(Venda entity) throws SQLException {
        String sqlCliente = "UPDATE Venda SET data=? WHERE id=?";
        String sqlEndereco = "UPDATE Pagamento SET descricao=?,efetuado=?,tipo=? WHERE id=?";

        PreparedStatement ps = getConnection().prepareStatement(sqlCliente, Statement.RETURN_GENERATED_KEYS);
        ps.setString(1, DateUtil.getDateString(entity.getData()));
        ps.setLong(2, entity.getId());
        ps.executeUpdate();

        Pagamento pagamento = entity.getPagamento();
        ps = getConnection().prepareStatement(sqlEndereco);
        ps.setString(1, pagamento.getDescricao());
        ps.setBoolean(2, pagamento.isEfetuado());
        ps.setString(3, pagamento.getTipo().toString());
        ps.setLong(4, pagamento.getId());
        ps.executeUpdate();

        updateItens(entity.getItens(), entity.getId());
    }

    @Override
    public void delete(long id) throws SQLException {
        String sql = "DELETE FROM Venda WHERE id = ?";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ps.setLong(1, id);
        ps.executeUpdate();
    }

    @Override
    public Venda parseResultSet(ResultSet resultSet) throws SQLException {
        ClienteDAO clienteDAO = new ClienteDAO();
        Cliente cliente = clienteDAO.parseResultSet(resultSet);//TODO MELHORAR (REDUZIR ACOPLAMENTO)

        Pagamento pagamento = new Pagamento();
        pagamento.setId(resultSet.getLong("pagamento.id"));
        pagamento.setDescricao(resultSet.getString("pagamento.descricao"));
        pagamento.setEfetuado(resultSet.getBoolean("pagamento.efetuado"));
        pagamento.setTipo(TipoPagamento.valueOf(resultSet.getString("pagamento.tipo")));

        Venda venda = new Venda();
        venda.setId(resultSet.getLong("venda.id"));
        venda.setData(DateUtil.getDate(resultSet.getString("venda.data")));
        venda.setCliente(cliente);
        venda.setPagamento(pagamento);
        return venda;
    }


    public Filtro parseFiltroResultSet(ResultSet resultSet) throws SQLException {
        ClienteDAO clienteDAO = new ClienteDAO();
        Cliente cliente = clienteDAO.parseResultSet(resultSet);//TODO MELHORAR (REDUZIR ACOPLAMENTO)

        ProdutoDAO produtoDAO = new ProdutoDAO();//TODO MELHORAR (REDUZIR ACOPLAMENTO)
        Produto produto = produtoDAO.parseResultSet(resultSet);

        Filtro filtro = new Filtro();
        filtro.setCliente(cliente);
        filtro.setProduto(produto);
        filtro.setQuantidade(resultSet.getLong("total"));
        return filtro;
    }

    private ArrayList<ItemVenda> getItens(long idVenda) throws SQLException {
        String sql = "SELECT * FROM ItemVenda item " +
                "INNER JOIN Produto produto ON produto.id = item.idProduto " +
                "INNER JOIN Categoria categoria ON categoria.id = produto.idCategoria " +
                "INNER JOIN Venda venda ON venda.id = item.idVenda " +
                "WHERE venda.id = ?";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ps.setLong(1, idVenda);
        ResultSet result = ps.executeQuery();
        ArrayList<ItemVenda> list = new ArrayList<>();
        while (result.next()) {
            ProdutoDAO produtoDAO = new ProdutoDAO();//TODO MELHORAR (REDUZIR ACOPLAMENTO)
            Produto produto = produtoDAO.parseResultSet(result);
            ItemVenda item = new ItemVenda();
            item.setProduto(produto);
            item.setQuantidade(result.getInt("item.quantidade"));
            list.add(item);
        }
        return list;
    }

    private void insertItens(Iterator<ItemVenda> itens, long idVenda) throws SQLException {
        while (itens.hasNext()) {
            ItemVenda item = itens.next();
            String sqlCliente = "INSERT INTO ItemVenda(idProduto, idVenda, quantidade) VALUES(?,?,?)";
            PreparedStatement ps = getConnection().prepareStatement(sqlCliente, Statement.RETURN_GENERATED_KEYS);
            ps.setLong(1, item.getProduto().getId());
            ps.setLong(2, idVenda);
            ps.setInt(3, item.getQuantidade());
            ps.executeUpdate();
        }
    }

    private void updateItens(Iterator<ItemVenda> itens, long idVenda) throws SQLException {
        while (itens.hasNext()) {
            ItemVenda item = itens.next();
            String sqlCliente = "UPDATE ItemVenda SET quantidade=? WHERE idProduto=? AND idVenda=?";
            PreparedStatement ps = getConnection().prepareStatement(sqlCliente, Statement.RETURN_GENERATED_KEYS);
            ps.setInt(1, item.getQuantidade());
            ps.setLong(2, item.getProduto().getId());
            ps.setLong(3, idVenda);
            ps.executeUpdate();
        }
    }

    public List<Filtro> filtro() throws SQLException {
        String sql = "SELECT *, SUM(item.quantidade) AS total " +
                "FROM Venda venda " +
                "INNER JOIN Pagamento pagamento ON pagamento.idVenda = venda.id " +
                "INNER JOIN Cliente cliente ON cliente.id = venda.idCliente " +
                "INNER JOIN Endereco endereco ON endereco.idCliente = cliente.id " +
                "INNER JOIN ItemVenda item ON venda.id = item.idVenda " +
                "INNER JOIN Produto produto ON produto.id = item.idProduto " +
                "INNER JOIN Categoria categoria ON categoria.id = produto.idCategoria " +
                "GROUP BY cliente.nome, produto.nome " +
                "ORDER BY cliente.nome, total DESC ";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ResultSet result = ps.executeQuery();
        List<Filtro> list = new ArrayList<>();
        while (result.next()) {
            list.add(parseFiltroResultSet(result));
        }
        return list;
    }

    public List<Filtro> filtro(long idCliente) throws SQLException {
        String sql = "SELECT *, SUM(item.quantidade) AS total " +
                "FROM Venda venda " +
                "INNER JOIN Pagamento pagamento ON pagamento.idVenda = venda.id " +
                "INNER JOIN Cliente cliente ON cliente.id = venda.idCliente " +
                "INNER JOIN Endereco endereco ON endereco.idCliente = cliente.id " +
                "INNER JOIN ItemVenda item ON venda.id = item.idVenda " +
                "INNER JOIN Produto produto ON produto.id = item.idProduto " +
                "INNER JOIN Categoria categoria ON categoria.id = produto.idCategoria " +
                "WHERE cliente.id = ? " +
                "GROUP BY cliente.nome, produto.nome " +
                "ORDER BY cliente.nome, total DESC ";
        PreparedStatement ps = getConnection().prepareStatement(sql);
        ps.setLong(1, idCliente);
        ResultSet result = ps.executeQuery();
        List<Filtro> list = new ArrayList<>();
        while (result.next()) {
            list.add(parseFiltroResultSet(result));
        }
        return list;
    }
}
