package com.iprj.apoo.crmpv.model.json;

import com.iprj.apoo.crmpv.model.entity.Cliente;
import com.iprj.apoo.crmpv.model.entity.Endereco;
import com.iprj.apoo.crmpv.model.entity.PessoaFisica;
import com.iprj.apoo.crmpv.model.entity.PessoaJuridica;
import com.iprj.apoo.crmpv.util.DateUtil;
import org.json.JSONArray;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;

/**
 * Created by guilherme on 10/07/15.
 */
public class ClienteFactory extends EntityFactory<Cliente> {
    @Override
    public Cliente getFromJSON(String json) {
        JSONObject jsonObject = new JSONObject(json);
        String type = jsonObject.getString("type");
        Endereco endereco = new EnderecoFactory().getFromJSON(jsonObject.getJSONObject("endereco").toString());

        Cliente cliente = new Cliente();

        if (type.equals(PessoaFisica.TYPE_NAME)) {
            cliente = new PessoaFisica();
            ((PessoaFisica) cliente).setCpf(jsonObject.getString("cpf"));

            Object dataNascimento = jsonObject.get("dataNascimento");
            if (dataNascimento instanceof Long) {
                ((PessoaFisica) cliente).setDataNascimento(new Date((Long) dataNascimento));
            } else {
                ((PessoaFisica) cliente).setDataNascimento(DateUtil.getDate((String) dataNascimento));
            }
        } else if (type.equals(PessoaJuridica.TYPE_NAME)) {
            cliente = new PessoaJuridica();
            ((PessoaJuridica) cliente).setCnpj(jsonObject.getString("cnpj"));
        }

        cliente.setId(jsonObject.optLong("id"));
        cliente.setNome(jsonObject.getString("nome"));
        cliente.setTelefone(jsonObject.getString("telefone"));
        cliente.setEmail(jsonObject.getString("email"));
        cliente.setEndereco(endereco);
        return cliente;
    }

    @Override
    public String parseToJSON(Cliente entity) {
        String endereco = new EnderecoFactory().parseToJSON(entity.getEndereco());

        JSONObject json = new JSONObject();
        json.put("id", entity.getId());
        json.put("nome", entity.getNome());
        json.put("telefone", entity.getTelefone());
        json.put("email", entity.getEmail());
        json.put("endereco", new JSONObject(endereco));

        if (entity instanceof PessoaFisica) {
            json.put("cpf", ((PessoaFisica) entity).getCpf());
            json.put("dataNascimento", ((PessoaFisica) entity).getDataNascimento().getTime());
            json.put("type", "PESSOA_FISICA");
        } else if (entity instanceof PessoaJuridica) {
            json.put("cnpj", ((PessoaJuridica) entity).getCnpj());
            json.put("type", "PESSOA_JURIDICA");
        }

        return json.toString();
    }

    @Override
    public ArrayList<Cliente> getFromJSONArray(String jsonArray) {
        JSONArray array = new JSONArray(jsonArray);
        ArrayList<Cliente> list = new ArrayList<>();
        for (int i = 0; i < array.length(); i++) {
            JSONObject entity = array.getJSONObject(i);
            list.add(getFromJSON(entity.toString()));
        }
        return list;
    }

    @Override
    public String parseCollectionToJSON(Collection<Cliente> collection) {
        JSONArray jsonArray = new JSONArray();
        for (Cliente entity : collection) {
            jsonArray.put(new JSONObject(parseToJSON(entity)));
        }
        return jsonArray.toString();
    }
}
