package com.iprj.apoo.crmpv.model.json;

import com.iprj.apoo.crmpv.model.entity.Cliente;
import com.iprj.apoo.crmpv.model.entity.ItemVenda;
import com.iprj.apoo.crmpv.model.entity.Pagamento;
import com.iprj.apoo.crmpv.model.entity.Venda;
import com.iprj.apoo.crmpv.util.DateUtil;
import org.json.JSONArray;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

/**
 * Created by guilherme on 10/07/15.
 */
public class VendaFactory extends EntityFactory<Venda> {
    @Override
    public Venda getFromJSON(String json) {
        JSONObject jsonObject = new JSONObject(json);
        Pagamento pagamento = new PagamentoFactory().getFromJSON(jsonObject.getJSONObject("pagamento").toString());
        Cliente cliente = new ClienteFactory().getFromJSON(jsonObject.getJSONObject("cliente").toString());

        Venda venda = new Venda();
        venda.setId(jsonObject.optLong("id"));
        venda.setData(DateUtil.getDate(jsonObject.getString("data")));
        venda.setPagamento(pagamento);
        venda.setCliente(cliente);

        JSONArray itensJson = jsonObject.getJSONArray("itens");
        for (int i = 0; i < itensJson.length(); i++) {
            ItemVenda item = new ItemVendaFactory().getFromJSON(itensJson.getJSONObject(i).toString());
            venda.addItem(item);
        }
        return venda;
    }

    @Override
    public String parseToJSON(Venda entity) {
        JSONArray itensJson = new JSONArray();
        Iterator<ItemVenda> itens = entity.getItens();
        while (itens.hasNext()) {
            String item = new ItemVendaFactory().parseToJSON(itens.next());
            itensJson.put(new JSONObject(item));
        }

        String pagamento = new PagamentoFactory().parseToJSON(entity.getPagamento());
        String cliente = new ClienteFactory().parseToJSON(entity.getCliente());

        JSONObject json = new JSONObject();
        json.put("id", entity.getId());
        json.put("data", DateUtil.getDateString(entity.getData()));
        json.put("total", entity.getTotal());
        json.put("itens", itensJson);
        json.put("pagamento", new JSONObject(pagamento));
        json.put("cliente", new JSONObject(cliente));
        return json.toString();
    }

    @Override
    public ArrayList<Venda> getFromJSONArray(String jsonArray) {
        JSONArray array = new JSONArray(jsonArray);
        ArrayList<Venda> list = new ArrayList<>();
        for (int i = 0; i < array.length(); i++) {
            JSONObject entity = array.getJSONObject(i);
            list.add(getFromJSON(entity.toString()));
        }
        return list;
    }

    @Override
    public String parseCollectionToJSON(Collection<Venda> collection) {
        JSONArray jsonArray = new JSONArray();
        for (Venda entity : collection) {
            jsonArray.put(new JSONObject(parseToJSON(entity)));
        }
        return jsonArray.toString();
    }
}
