<%@ page contentType="text/html;charset=UTF-8" pageEncoding="UTF-8" language="java" %>
<%@taglib prefix="t" tagdir="/WEB-INF/tags" %>
<%@ taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core" %>
<t:dashboard>

    <jsp:attribute name="script">
        <script src="<c:url value="/js/controllers/venda.controller.js"/>"></script>
    </jsp:attribute>

    <jsp:body>
        <div class="container-fluid" ng-controller="VendaController">
            <div class="row">
                <div class="col-lg-10 col-lg-offset-1">

                    <alert ng-repeat="alert in alerts" type="{{alert.type}}" close="closeAlert($index)">{{alert.msg}}
                    </alert>
                    
                    <div class="row">
                        <div class="col-lg-12">
                            <form ng-submit="submitForm()" name="vendaForm">
                                <div class="panel panel-primary">
                                    <div class="panel-heading">
                                        <span>Cadastrar venda</span>
                                    </div>
                                    <div class="panel-body">
                                        <div class="row">
                                            <div class="col-lg-12">
                                                <fieldset>
                                                    <legend>Informações da venda</legend>
                                                    <div class="form-group">
                                                        <label for="venda.cliente">Cliente</label>
                                                        <select ng-options="cliente as cliente.nome for cliente in clienteList"
                                                                ng-model="venda.cliente" class="form-control"
                                                                id="venda.cliente" required>
                                                        </select>
                                                    </div>
                                                    <div class="form-group">
                                                        <label for="venda.data">Data</label>
                                                        <input type="date" ng-model="venda.data"
                                                               id="venda.data"
                                                               class="form-control"/>
                                                    </div>
                                                </fieldset>

                                                <fieldset>
                                                    <legend>Informações de pagamento</legend>
                                                    <div class="form-group">
                                                        <label for="venda.pagamento.tipo">Tipo de pagamento</label>
                                                        <select ng-model="venda.pagamento.tipo" class="form-control"
                                                                id="venda.pagamento.tipo" required>
                                                            <option value="CARTAO_DEBITO">Cartão de débito</option>
                                                            <option value="CARTAO_CREDITO">Cartão de crédito</option>
                                                            <option value="CHEQUE_PRE">Cheque pré</option>
                                                            <option value="CHEQUE_AVISTA">Cheque a vista</option>
                                                            <option value="DINHEIRO">Dinheiro</option>
                                                        </select>
                                                    </div>
                                                    <div class="form-group">
                                                        <label for="venda.pagamento.descricao">Descrição</label>
                                                        <input type="text" ng-model="venda.pagamento.descricao"
                                                               id="venda.pagamento.descricao"
                                                               placeholder="Descrição do pagamento"
                                                               class="form-control"/>
                                                    </div>
                                                    <div class="form-group">
                                                        <label>Status do pagamento</label>

                                                        <div class="form-control-static">
                                                            <label class="radio-inline">
                                                                <input type="radio" ng-model="venda.pagamento.efetuado"
                                                                       value="true">Efetuado
                                                            </label>
                                                            <label class="radio-inline">
                                                                <input type="radio" ng-model="venda.pagamento.efetuado"
                                                                       value="false">Não efetuado
                                                            </label>
                                                        </div>
                                                    </div>
                                                </fieldset>

                                                <fieldset>
                                                    <legend>Produtos</legend>
                                                    <div ng-repeat="item in venda.itens">
                                                        <div class="row">
                                                            <div class="col-lg-6">
                                                                <div class="form-group">
                                                                    <label for="item.produto">Produto</label>
                                                                    <select ng-options="produto as produto.nome for produto in produtoList"
                                                                            ng-model="item.produto"
                                                                            class="form-control"
                                                                            id="item.produto" required>
                                                                    </select>
                                                                </div>
                                                            </div>
                                                            <div class="col-lg-3">
                                                                <div class="form-group">
                                                                    <label for="item.quantidade">Quantidade</label>
                                                                    <input type="text" ng-model="item.quantidade"
                                                                           id="item.quantidade"
                                                                           class="form-control"
                                                                           placeholder="Insira uma quantidade"
                                                                           required/>
                                                                </div>
                                                            </div>
                                                            <div class="col-lg-3">
                                                                <div class="form-group">
                                                                    <label>Preço</label>

                                                                    <div class="input-group">
                                                                        <span class="form-control" type="text"
                                                                              placeholder="Sub-total" readonly>
                                                                            {{(item.produto.preco * item.quantidade) | currency:'R$'}}
                                                                        </span>
                                                                      <span class="input-group-btn">
                                                                        <button ng-click="removeItem(item)"
                                                                                class="btn btn-danger" type="button">
                                                                            <span class="glyphicon glyphicon-remove"
                                                                                  aria-hidden="true"></span>
                                                                        </button>
                                                                      </span>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>

                                                    <div class="row">
                                                        <div class="col-lg-9 text-center">
                                                            <button ng-click="addItem()" class="btn btn-info"
                                                                    type="button">
                                                                <span class="glyphicon glyphicon-plus-sign"
                                                                      aria-hidden="true"></span>
                                                                Adicionar produto
                                                            </button>
                                                        </div>
                                                        <div class="col-lg-3">
                                                            <div class="form-group">
                                                                <label>Total</label>
                                                                <span class="form-control" type="text"
                                                                      placeholder="Total" readonly>{{ total() | currency:'R$'}}
                                                                </span>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </fieldset>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="panel-footer text-center">
                                        <button class="btn btn-success" type="submit">Salvar</button>
                                        <button ng-click="resetForm()" class="btn btn-default" type="button">Cancelar
                                        </button>
                                    </div>
                                </div>

                            </form>
                        </div>
                    </div>

                </div>
            </div>
        </div>
    </jsp:body>

</t:dashboard>