angular.module('crmpv').controller('CategoriaController', ['$scope', '$http', function ($scope, $http) {

    $scope.initial = {
        categoria: {}
    };

    $scope.categoria = angular.copy($scope.initial.categoria);
    $scope.categoriaList = [];
    $scope.alerts = [];

    $scope.getAll = function () {
        var response = $http.get('/categoria/get');

        response.success(function (data, status, headers, config) {
            $scope.categoriaList = data;
        });

        response.error(function (data, status, headers, config) {
            console.log(data);
            $scope.addAlert({type: 'danger', msg: data});
        });
    };

    $scope.insert = function () {
        var response = $http.post('/categoria/insert', $scope.categoria);

        response.success(function (data, status, headers, config) {
            $scope.resetForm();
            $scope.getAll();
            $scope.addAlert({type: 'success', msg: 'Categoria inserida com sucesso!'});
        });

        response.error(function (data, status, headers, config) {
            console.log(data);
            $scope.addAlert({type: 'danger', msg: data});
        });
    };

    $scope.update = function () {
        var response = $http.post('/categoria/update', $scope.categoria);

        response.success(function (data, status, headers, config) {
            $scope.resetForm();
            $scope.addAlert({type: 'success', msg: 'Categoria atualizada com sucesso!'});
        });

        response.error(function (data, status, headers, config) {
            console.log(data);
            $scope.addAlert({type: 'danger', msg: data});
        });
    };

    $scope.delete = function (categoria) {
        var response = $http.get('/categoria/delete/' + categoria.id);

        response.success(function (data, status, headers, config) {
            var index = $scope.categoriaList.indexOf(categoria);
            $scope.categoriaList.splice(index, 1);
            $scope.resetForm();
            $scope.addAlert({type: 'success', msg: 'Categoria removida com sucesso!'});
        });

        response.error(function (data, status, headers, config) {
            console.log(data);
            $scope.addAlert({type: 'danger', msg: data});
        });
    };

    $scope.setModel = function (model) {
        $scope.categoria = model;
    };

    $scope.submitForm = function () {
        if ($scope.categoria.id === undefined) {
            $scope.insert();
        } else {
            $scope.update($scope.categoria);
        }
    };

    $scope.resetForm = function () {
        $scope.categoria = angular.copy($scope.initial.categoria);
        $scope.categoriaForm.$setPristine();
    };

    $scope.addAlert = function (alert) {
        $scope.alerts.push(alert);
    };

    $scope.closeAlert = function (index) {
        $scope.alerts.splice(index, 1);
    };

    $scope.getAll();

}]);