angular.module('crmpv').controller('ClienteController', ['$scope', '$http', '$filter', function ($scope, $http, $filter) {

    $scope.initial = {
        cliente: {
            type: 'PESSOA_FISICA',
            dataNascimento: new Date(1990, 1, 1),
            endereco: {
                uf: 'RJ'
            }
        }
    };

    $scope.cliente = angular.copy($scope.initial.cliente);
    $scope.clienteList = [];
    $scope.alerts = [];

    $scope.getAll = function () {
        var response = $http.get('/cliente/get');

        response.success(function (data, status, headers, config) {
            $scope.clienteList = data;
        });

        response.error(function (data, status, headers, config) {
            console.log(data);
            $scope.addAlert({type: 'danger', msg: data});
        });
    };

    $scope.insert = function () {
        var response = $http.post('/cliente/insert', $scope.cliente);

        response.success(function (data, status, headers, config) {
            $scope.resetForm();
            $scope.getAll();
            $scope.addAlert({type: 'success', msg: 'Cliente inserido com sucesso!'});
        });

        response.error(function (data, status, headers, config) {
            console.log(data);
            $scope.addAlert({type: 'danger', msg: data});
        });
    };

    $scope.update = function () {
        var response = $http.post('/cliente/update', $scope.cliente);

        response.success(function (data, status, headers, config) {
            $scope.resetForm();
            $scope.addAlert({type: 'success', msg: 'Cliente atualizado com sucesso!'});
        });

        response.error(function (data, status, headers, config) {
            console.log(data);
            $scope.addAlert({type: 'danger', msg: data});
        });
    };

    $scope.delete = function (cliente) {
        var response = $http.get('/cliente/delete/' + cliente.id);

        response.success(function (data, status, headers, config) {
            var index = $scope.clienteList.indexOf(cliente);
            $scope.clienteList.splice(index, 1);
            $scope.resetForm();
            $scope.addAlert({type: 'success', msg: 'Cliente removido com sucesso!'});
        });

        response.error(function (data, status, headers, config) {
            console.log(data);
            $scope.addAlert({type: 'danger', msg: data});
        });
    };

    $scope.setModel = function (model) {
        $scope.cliente = model;
    };

    $scope.submitForm = function () {
        if ($scope.cliente.id === undefined) {
            $scope.insert();
        } else {
            $scope.update($scope.cliente);
        }
    };

    $scope.resetForm = function () {
        $scope.cliente = angular.copy($scope.initial.cliente);
        $scope.clienteForm.$setPristine();
    };

    $scope.addAlert = function (alert) {
        $scope.alerts.push(alert);
    };

    $scope.closeAlert = function (index) {
        $scope.alerts.splice(index, 1);
    };

    $scope.$watch('cliente.dataNascimento', function (newValue) {
        if (!(newValue instanceof Date)) {
            $scope.cliente.dataNascimento = new Date(newValue);
        }
    });

    $scope.getAll();

}]);