angular.module('crmpv').controller('ProdutoController', ['$scope', '$http', function ($scope, $http) {

    $scope.initial = {
        produto: {}
    };

    $scope.produto = angular.copy($scope.initial.produto);
    $scope.produtoList = [];
    $scope.categoriaList = [];
    $scope.alerts = [];

    $scope.getAll = function () {
        var response = $http.get('/produto/get');

        response.success(function (data, status, headers, config) {
            $scope.produtoList = data;
        });

        response.error(function (data, status, headers, config) {
            console.log(data);
            $scope.addAlert({type: 'danger', msg: data});
        });
    };

    $scope.insert = function () {
        var response = $http.post('/produto/insert', $scope.produto);

        response.success(function (data, status, headers, config) {
            $scope.resetForm();
            $scope.getAll();
            $scope.addAlert({type: 'success', msg: 'Produto inserido com sucesso!'});
        });

        response.error(function (data, status, headers, config) {
            console.log(data);
            $scope.addAlert({type: 'danger', msg: data});
        });
    };

    $scope.update = function () {
        var response = $http.post('/produto/update', $scope.produto);

        response.success(function (data, status, headers, config) {
            $scope.resetForm();
            $scope.addAlert({type: 'success', msg: 'Produto atualizado com sucesso!'});
        });

        response.error(function (data, status, headers, config) {
            console.log(data);
            $scope.addAlert({type: 'danger', msg: data});
        });
    };

    $scope.delete = function (produto) {
        var response = $http.get('/produto/delete/' + produto.id);

        response.success(function (data, status, headers, config) {
            var index = $scope.produtoList.indexOf(produto);
            $scope.produtoList.splice(index, 1);
            $scope.resetForm();
            $scope.addAlert({type: 'success', msg: 'Produto removido com sucesso!'});
        });

        response.error(function (data, status, headers, config) {
            console.log(data);
            $scope.addAlert({type: 'danger', msg: data});
        });
    };

    $scope.getAllCategoria = function () {
        var response = $http.get('/categoria/get');

        response.success(function (data, status, headers, config) {
            $scope.categoriaList = data;
        });

        response.error(function (data, status, headers, config) {
            console.log(data);
            $scope.addAlert({type: 'danger', msg: data});
        });
    };

    $scope.setModel = function (model) {
        $scope.produto = model;
    };

    $scope.submitForm = function () {
        if ($scope.produto.id === undefined) {
            $scope.insert();
        } else {
            $scope.update($scope.produto);
        }
    };

    $scope.resetForm = function () {
        $scope.produto = angular.copy($scope.initial.produto);
        $scope.produtoForm.$setPristine();
    };

    $scope.addAlert = function (alert) {
        $scope.alerts.push(alert);
    };

    $scope.closeAlert = function (index) {
        $scope.alerts.splice(index, 1);
    };

    $scope.getAll();
    $scope.getAllCategoria();

}]);