angular.module('crmpv').controller('UsuarioController', ['$scope', '$http', '$filter', function ($scope, $http, $filter) {

    $scope.initial = {
        usuario: {
            dataNascimento: new Date(1990, 1, 1),
            cargo: 'USUARIO',
            endereco: {
                uf: 'RJ'
            }
        }
    };

    $scope.usuario = angular.copy($scope.initial.usuario);
    $scope.usuarioList = [];
    $scope.alerts = [];

    $scope.getAll = function () {
        var response = $http.get('/usuario/get');

        response.success(function (data, status, headers, config) {
            $scope.usuarioList = data;
        });

        response.error(function (data, status, headers, config) {
            console.log(data);
            $scope.addAlert({type: 'danger', msg: data});
        });
    };

    $scope.insert = function () {
        var response = $http.post('/usuario/insert', $scope.usuario);

        response.success(function (data, status, headers, config) {
            $scope.resetForm();
            $scope.getAll();
            $scope.addAlert({type: 'success', msg: 'Usuário inserido com sucesso!'});
        });

        response.error(function (data, status, headers, config) {
            console.log(data);
            $scope.addAlert({type: 'danger', msg: data});
        });
    };

    $scope.update = function () {
        var response = $http.post('/usuario/update', $scope.usuario);

        response.success(function (data, status, headers, config) {
            $scope.resetForm();
            $scope.addAlert({type: 'success', msg: 'Usuário atualizado com sucesso!'});
        });

        response.error(function (data, status, headers, config) {
            console.log(data);
            $scope.addAlert({type: 'danger', msg: data});
        });
    };

    $scope.delete = function (usuario) {
        var response = $http.get('/usuario/delete/' + usuario.id);

        response.success(function (data, status, headers, config) {
            var index = $scope.usuarioList.indexOf(usuario);
            $scope.usuarioList.splice(index, 1);
            $scope.resetForm();
            $scope.addAlert({type: 'success', msg: 'Usuário removido com sucesso!'});
        });

        response.error(function (data, status, headers, config) {
            console.log(data);
            $scope.addAlert({type: 'danger', msg: data});
        });
    };

    $scope.setModel = function (model) {
        $scope.usuario = model;
    };

    $scope.submitForm = function () {
        if ($scope.usuario.id === undefined) {
            $scope.insert();
        } else {
            $scope.update($scope.usuario);
        }
    };

    $scope.resetForm = function () {
        $scope.usuario = angular.copy($scope.initial.usuario);
        $scope.usuarioForm.$setPristine();
    };

    $scope.addAlert = function (alert) {
        $scope.alerts.push(alert);
    };

    $scope.closeAlert = function (index) {
        $scope.alerts.splice(index, 1);
    };

    $scope.$watch('usuario.dataNascimento', function (newValue) {
        if (!(newValue instanceof Date)) {
            $scope.usuario.dataNascimento = new Date(newValue);
        }
    });

    $scope.getAll();

}]);